"use strict";

exports.__esModule = true;
exports["default"] = extractOpenArguments;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _astToReference = require("./ast/to-reference");

var _astToReference2 = _interopRequireDefault(_astToReference);

// Extracts attributes into the appropriate
// attribute array. Static attributes and the key
// are placed into static attributes, and expressions
// are placed into the variadic attributes.

function extractOpenArguments(t, scope, attributes, eager) {
  var attributeDeclarators = [];
  var attrs = [];
  var hasSpread = false;
  var key = null;
  var statics = [];

  attributes.forEach(function (attribute) {
    if (t.isJSXSpreadAttribute(attribute)) {
      hasSpread = true;
      attrs.push(attribute);
      return;
    }

    var attr = _astToReference2["default"](t, attribute.name);
    var name = attr.value;
    var value = attribute.value;

    if (t.isJSXExpressionContainer(value)) {
      value = value.expression;

      if (eager && !t.isLiteral(value) && !value._iDOMwasJSX) {
        var ref = scope.generateUidIdentifierBasedOnNode(value);
        attributeDeclarators.push(t.variableDeclarator(ref, value));
        value = ref;
      }
    } else if (!value) {
      value = t.literal(true);
    }

    if (name === "key") {
      key = value;
    }

    if (name === "key" || t.isLiteral(value)) {
      statics.push(attr, value);
    } else {
      attrs.push(attr, value);
    }
  });

  if (!statics.length) {
    statics = null;
  }
  if (!attrs.length) {
    attrs = null;
  }

  return { key: key, statics: statics, attrs: attrs, attributeDeclarators: attributeDeclarators, hasSpread: hasSpread };
}

module.exports = exports["default"];